"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getHighlighter = getHighlighter;
exports.getSafeLanguage = getSafeLanguage;
exports.isValidLanguage = isValidLanguage;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _githubDark = _interopRequireDefault(require("shiki/dist/themes/github-dark.mjs"));
var _css = _interopRequireDefault(require("shiki/dist/langs/css.mjs"));
var _html = _interopRequireDefault(require("shiki/dist/langs/html.mjs"));
var _javascript = _interopRequireDefault(require("shiki/dist/langs/javascript.mjs"));
var _json = _interopRequireDefault(require("shiki/dist/langs/json.mjs"));
var _markdown = _interopRequireDefault(require("shiki/dist/langs/markdown.mjs"));
var _php = _interopRequireDefault(require("shiki/dist/langs/php.mjs"));
var _tsx = _interopRequireDefault(require("shiki/dist/langs/tsx.mjs"));
var _typescript = _interopRequireDefault(require("shiki/dist/langs/typescript.mjs"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/* eslint-disable no-console */

// Import languages

const DEBUG = true;
function log(message, ...args) {
  if (DEBUG) {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}
// Define raw languages with proper typing
const rawLanguages = {
  typescript: _typescript.default,
  javascript: _javascript.default,
  json: _json.default,
  html: _html.default,
  css: _css.default,
  markdown: _markdown.default,
  tsx: _tsx.default,
  php: _php.default,
  plaintext: {
    id: 'plaintext',
    scopeName: 'source.plaintext',
    grammar: {
      patterns: [{
        match: '.*',
        name: 'text.plain'
      }]
    }
  }
};
let highlighterInstance = null;

// Process raw languages into LanguageRegistrations
function processLanguages() {
  return Object.entries(rawLanguages).map(([key, lang]) => ({
    name: lang.id || key,
    scopeName: lang.scopeName,
    patterns: lang.patterns || [],
    repository: lang.repository || {},
    aliases: lang.aliases || [],
    embeddedLangs: lang.embeddedLanguages || [],
    grammar: lang.grammar || {}
  }));
}
async function getHighlighter() {
  if (highlighterInstance) {
    log('Returning cached highlighter instance');
    return highlighterInstance;
  }
  try {
    log('Creating new highlighter instance...');

    // Create engine
    const engine = (0, _engineJavascript.createJavaScriptRegexEngine)();

    // Process languages
    const languages = processLanguages();

    // Create highlighter
    highlighterInstance = await (0, _core.createHighlighterCore)({
      themes: [(0, _core.normalizeTheme)(_githubDark.default)],
      langs: languages,
      engine
    });
    if (!highlighterInstance) {
      throw new Error('Failed to create highlighter instance');
    }
    const loadedLangs = highlighterInstance.getLoadedLanguages();
    log('Successfully loaded languages:', loadedLangs);
    return highlighterInstance;
  } catch (error) {
    log('Error creating highlighter:', error);
    throw error;
  }
}
function isValidLanguage(lang) {
  const normalized = lang.toLowerCase();
  return Object.keys(rawLanguages).includes(normalized);
}
function getSafeLanguage(lang) {
  const normalized = lang.toLowerCase();
  if (isValidLanguage(normalized)) {
    return normalized;
  }
  log(`Warning: Unsupported language '${lang}', falling back to plaintext`);
  return 'plaintext';
}
//# sourceMappingURL=SyntaxContext.js.map